summaryrefslogtreecommitdiff
path: root/sd/source/ui/func/fulinend.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/func/fulinend.cxx')
-rwxr-xr-x[-rw-r--r--]sd/source/ui/func/fulinend.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sd/source/ui/func/fulinend.cxx b/sd/source/ui/func/fulinend.cxx
index 9c53518507f3..30292667bc3e 100644..100755
--- a/sd/source/ui/func/fulinend.cxx
+++ b/sd/source/ui/func/fulinend.cxx
@@ -95,10 +95,10 @@ void FuLineEnd::DoExecute( SfxRequest& )
if( aInfoRec.bCanConvToPath &&
pObj->GetObjInventor() == SdrInventor &&
pObj->GetObjIdentifier() != OBJ_GRUP )
// bCanConvToPath ist bei Gruppenobjekten TRUE,
// stuerzt aber bei ConvertToPathObj() ab !
{
- pNewObj = pConvPolyObj = pObj->ConvertToPolyObj( TRUE, FALSE );
+ pNewObj = pConvPolyObj = pObj->ConvertToPolyObj( sal_True, sal_False );
if( !pNewObj || !pNewObj->ISA( SdrPathObj ) )
return; // Abbruch, zusaetzliche Sicherheit, die bei
@@ -121,18 +121,18 @@ void FuLineEnd::DoExecute( SfxRequest& )
long nCount = pLineEndList->Count();
long j = 1;
- BOOL bDifferent = FALSE;
+ sal_Bool bDifferent = sal_False;
while( !bDifferent )
{
aName = aNewName;
aName.Append( sal_Unicode(' ') );
aName.Append( UniString::CreateFromInt32( j++ ) );
- bDifferent = TRUE;
+ bDifferent = sal_True;
for( long i = 0; i < nCount && bDifferent; i++ )
{
if( aName == pLineEndList->GetLineEnd( i )->GetName() )
- bDifferent = FALSE;
+ bDifferent = sal_False;
}
}
@@ -146,12 +146,12 @@ void FuLineEnd::DoExecute( SfxRequest& )
if( pDlg->Execute() == RET_OK )
{
pDlg->GetName( aName );
- bDifferent = TRUE;
+ bDifferent = sal_True;
for( long i = 0; i < nCount && bDifferent; i++ )
{
if( aName == pLineEndList->GetLineEnd( i )->GetName() )
- bDifferent = FALSE;
+ bDifferent = sal_False;
}
if( bDifferent )
@@ -95,10 +95,10 @@ void FuLineEnd::DoExecute( SfxRequest& )
pObj->GetObjInventor() == SdrInventor &&
pObj->GetObjIdentifier() != OBJ_GRUP )
- // bCanConvToPath ist bei Gruppenobjekten TRUE,
+ // bCanConvToPath ist bei Gruppenobjekten sal_True,
// stuerzt aber bei ConvertToPathObj() ab !
{